referee

# XMLRésuméLibrary: User Guide

pubs | Element Reference | referees

## Name

referee — Someone who can provide additional information about the person the résumé describes

## Synopsis

### Content Model

    (name,title?,organization?,address?,contact?)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `referee` element contains the name and contact information information of a person who knows the job seeker (the person that the résumé describes). Referees (also called references) can provide additional information about the job seeker. They often supply background information, confirm facts, and describe the job seeker's character.

### Formatting

The display of `referee` is influenced by the `referees.display` parameter.

### Parents

`referee` may be contained in these elements: `referees`

## Examples

    <referee>
      <name>Joe</name>
      <address>
        <street>123 Main St.</street>
        <city>Anytown</city>
        <state>ST</state>
        <zip>12345</zip>
        <country>USA</country>
      </address>
      <contact>
        <phone>123.456.7890</phone>
        <email>joe@hotmail.bob</email>
      </contact>
    </referee>

For additional examples, see `referees`.

pubs | Element Reference | referees